AwesomePlaceSearch class

AwesomePlaceSearch This is the Main Class

Constructors

AwesomePlaceSearch({required BuildContext context, InputDecoration? searchTextFieldDecoration, required String apiKey, double modalBorderRadius = 15.0, double? elevation, double dividerItemWidth = 0.2, List<String> countries = const [], String errorText = "something went wrong", String hint = "Where are we going?", required dynamic onTap(Future<PredictionModel>), Widget? invalidKeyWidget, Widget? onErrorWidget, Widget? loadingWidget, Color? dividerItemColor, Widget? placeIconWidget, Color? indicatorColor, TextStyle? subtitleStyle, TextStyle? titleStyle, bool autofocus = false})

Properties

apiKey String
final
autofocus bool
final
context BuildContext
final
countries List<String>
final
dependencies → Dependencies
final
dividerItemColor Color?
final
dividerItemWidth double
final
elevation double?
final
errorText String
final
hashCode int
The hash code for this object.
no setterinherited
hint String
final
indicatorColor Color?
final
invalidKeyWidget Widget?
final
loadingWidget Widget?
final
modalBorderRadius double
final
onErrorWidget Widget?
final
onTap → dynamic Function(Future<PredictionModel>)
final
placeIconWidget Widget?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchTextFieldDecoration InputDecoration?
final
subtitleStyle TextStyle?
final
titleStyle TextStyle?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
show() → void
show Show modal to search places
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited